summaryrefslogtreecommitdiffstats
path: root/alerts.c
diff options
context:
space:
mode:
authornicm <nicm>2017-08-16 11:46:08 +0000
committernicm <nicm>2017-08-16 11:46:08 +0000
commitc1ec28a34bea8759481308425d7918721ef62a94 (patch)
treea5dae9ea676275bf3b64c30add3b3411398f1898 /alerts.c
parentac2ba0961babe8307b6474a73ea11b097b42f759 (diff)
Rename BELL_* values to ALERT_* now they are used by more than bells,
based on a diff from Brad Town.
Diffstat (limited to 'alerts.c')
-rw-r--r--alerts.c14
1 files changed, 7 insertions, 7 deletions
diff --git a/alerts.c b/alerts.c
index 790ce38e..9c9bdf3b 100644
--- a/alerts.c
+++ b/alerts.c
@@ -267,11 +267,11 @@ alerts_set_message(struct session *s, struct window *w, struct winlink *wl,
int flag;
/*
- * We have found an alert (bell, activity or silence), so we need
- * to notify the user. For each client attached to this session,
+ * We have found an alert (bell, activity or silence), so we need to
+ * pass it on to the user. For each client attached to this session,
* decide whether a bell (or visual message) is needed.
*
* {bell,activity,silence}-action determines when we notify: none means
* nothing happens, current means we only do something for the current
* window and other means only for windows other than the current.
*
@@ -280,17 +280,17 @@ alerts_set_message(struct session *s, struct window *w, struct winlink *wl,
* mean both a bell and visual message is sent.
*/
- if (action == BELL_NONE)
+ if (action == ALERT_NONE)
return;
TAILQ_FOREACH(c, &clients, entry) {
if (c->session != s || c->flags & CLIENT_CONTROL)
continue;
flag = 0;
- if (action == BELL_ANY)
+ if (action == ALERT_ANY)
flag = 1;
- else if (action == BELL_CURRENT)
+ else if (action == ALERT_CURRENT)
flag = (c->session->curw->window == w);
- else if (action == BELL_OTHER)
+ else if (action == ALERT_OTHER)
flag = (c->session->curw->window != w);
if (!flag)
continue;
@@ -267,11 +267,11 @@ alerts_set_message(struct session *s, struct window *w, struct winlink *wl,
* decide whether a bell (or visual message) is needed.
*
- * {bell,activity,silence}-action determines when we notify: none means
+ * {bell,activity,silence}-action determines when we alert: none means
* nothing happens, current means we only do something for the current
* window and other means only for windows other than the current.